@@ -1,4 +1,5 @@
 """Build CQL queries from Pydantic models."""
+import base64
 import datetime
 import inspect
 import typing
@@ -41,6 +42,7 @@ class QueryBuilder(Generic[ModelType]):
         keyspace: str,
         model_type: Type[ModelType],
         metadata: TableMetadata,
+        default_page_size: int,
     ) -> None:
         """Init an instance the QueryBuilder class.
 
@@ -48,7 +50,9 @@ class QueryBuilder(Generic[ModelType]):
         :param keyspace: Keyspace of the tables.
         :param model_type: Type of model this instance will manage.
         :param metadata: Metadata about this table.
+        :param default_page_size: Default size of paginated results.
         """
+        self.default_page_size = default_page_size
         self._session = session
         self._keyspace = keyspace or session.keyspace
         self._model_type = model_type
@@ -99,8 +103,7 @@ class QueryBuilder(Generic[ModelType]):
         :param paging_state: State of pagination.
         :return: A model representing the record if one is found.
         """
-        # 5000 is cassandra-driver default.
-        page_size = 5000 if page_size is None else page_size
+        page_size = self.default_page_size if page_size is None else page_size
         where = where if where is not None else {}
         # Determine which columns will be `? =` vs `? CONTAINS`.
         contains_columns = [
@@ -123,6 +126,7 @@ class QueryBuilder(Generic[ModelType]):
         self._session.default_fetch_size = page_size
         values = [where[c] for c in filter_columns + contains_columns]
         if paging_state is not None:
+            paging_state = base64.b64decode(paging_state)
             results = self._session.execute(query, values, paging_state=paging_state)
         else:
             results = self._session.execute(query, values)
@@ -132,7 +136,11 @@ class QueryBuilder(Generic[ModelType]):
             models.append(self._deserialize(row))
             if i == page_size - 1:
                 break
-        return PaginatedResult(results=models, paging_state=results.paging_state)
+        if results.paging_state:
+            result_paging_state = base64.b64encode(results.paging_state)
+        else:
+            result_paging_state = results.paging_state
+        return PaginatedResult(results=models, paging_state=result_paging_state)
 
     async def insert(self, model: ModelType) -> None:
         """Insert a record from a model.
